

if __name__ == "__main__":
    print(f"####### playground #######")
    from utils.search import create_collection, create_dummy_data, get_indexer, search_doc
    # ix, created = create_collection()
    # print(ix)
    # print(f"is collection newly created? {created}")
    # ix = get_indexer()
    # print(ix.doc_count())
    # print(create_dummy_data())
    # print(search_doc("content", "example"))
    # print(search_doc("title", "Second"))
    # print(search_doc("content", "this AND (title:Second)"))

